@@ -142,6 +142,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/container.h>
 #include <gtkmm/cssprovider.h>
+#include <gtkmm/csssection.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/drawingarea.h>
 #include <gtkmm/editable.h>
@@ -173,6 +174,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/gesturesingle.h>
 #include <gtkmm/gestureswipe.h>
 #include <gtkmm/gesturezoom.h>
+#include <gtkmm/glarea.h>
 #include <gtkmm/grid.h>
 #include <gtkmm/handlebox.h>
 #include <gtkmm/headerbar.h>
@@ -208,6 +210,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/menushell.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/misc.h>
+#include <gtkmm/modelbutton.h>
 #include <gtkmm/notebook.h>
 #include <gtkmm/numerableicon.h>
 #include <gtkmm/object.h>
@@ -221,6 +224,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/papersize.h>
 #include <gtkmm/placessidebar.h>
 #include <gtkmm/popover.h>
+#include <gtkmm/popovermenu.h>
 #include <gtkmm/printcontext.h>
 #ifndef G_OS_WIN32
 # include <gtkmm/printer.h>
@@ -256,16 +260,23 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/separatormenuitem.h>
 #include <gtkmm/separatortoolitem.h>
 #include <gtkmm/settings.h>
+#include <gtkmm/shortcutlabel.h>
+#include <gtkmm/shortcutsgroup.h>
+#include <gtkmm/shortcutssection.h>
+#include <gtkmm/shortcutsshortcut.h>
+#include <gtkmm/shortcutswindow.h>
 #include <gtkmm/sizegroup.h>
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/spinner.h>
 #include <gtkmm/stack.h>
+#include <gtkmm/stacksidebar.h>
 #include <gtkmm/stackswitcher.h>
 #include <gtkmm/statusbar.h>
 #include <gtkmm/statusicon.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/stockitem.h>
 #include <gtkmm/stylecontext.h>
+#include <gtkmm/styleproperty.h>
 #include <gtkmm/switch.h>
 #include <gtkmm/table.h>
 #include <gtkmm/tearoffmenuitem.h>
